# Changelog

All notable changes to this project will be documented in this file.

## [0.0.1] - 2025-03-31

### Added
- Support for client-go dynamic client
- Support for envtest
- Support for setup-envtest
- Initial examples for the project